@@ -10,25 +10,25 @@ use Test::Mojo;
 use Test::More ();
 
 $ENV{MOJO_LOG_LEVEL} = $ENV{HARNESS_IS_VERBOSE} ? 'debug' : 'error';
-$ENV{TEST_HOME} = path(__FILE__)->to_abs->dirname;
+$ENV{TEST_HOME}      = path(__FILE__)->to_abs->dirname;
 
 END { cleanup() }
 
 my %CREATED_FILES;
 
 unless ($ENV{TEST_KEEP_FILES}) {
-  my $spurt = \&Mojo::File::spurt;
+  my $spew = \&Mojo::File::spew;
   Mojo::Util::monkey_patch(
-    'Mojo::File' => spurt => sub {
+    'Mojo::File' => spew => sub {
       $CREATED_FILES{$_[0]} = 1 unless -e $_[0];
-      goto $spurt;
+      goto $spew;
     }
   );
 }
 
 sub cleanup {
   $CREATED_FILES{path($ENV{TEST_HOME}, 'assets', $ENV{MOJO_ASSETPACK_DB_FILE})} = 1
-    if $ENV{MOJO_ASSETPACK_DB_FILE};
+    if $ENV{MOJO_ASSETPACK_DB_FILE} and !$ENV{TEST_KEEP_FILES};
   unlink $_ for keys %CREATED_FILES;
 }
 
